@@ -10,7 +10,7 @@ from monitor.entities.ScreenshotStatistics import ScreenshotStatistics
 from monitor.entities.SmartBOT import SmartBOT
 from monitor.entities.performance.Activity import Activity
 from monitor.performance.CpuMonitor import CpuMonitor
-from monitor.performance.ScreenShotGenerator import ScreenShotGenerator, screenshots
+from monitor.performance.ScreenShotGenerator import ScreenShotGenerator
 from monitor.services.ScenariosServiceImpl import ScenariosServiceImpl
 from monitor.utils.Commons import Commons
 
